@@ -14,7 +14,6 @@
 #    under the License.
 
 from tempest import config
-import testtools
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
@@ -26,11 +25,16 @@ CONF = config.CONF
 _MIN_SUPPORTED_MICROVERSION = '2.11'
 
 
-@testtools.skipUnless(CONF.share.run_replication_tests,
-                      'Replication tests are disabled.')
-@base.skip_if_microversion_lt(_MIN_SUPPORTED_MICROVERSION)
 class ReplicationAdminTest(base.BaseSharesMixedTest):
 
+    @classmethod
+    def skip_checks(cls):
+        super(ReplicationAdminTest, cls).skip_checks()
+        if not CONF.share.run_replication_tests:
+            raise cls.skipException('Replication tests are disabled.')
+
+        utils.check_skip_if_microversion_lt(_MIN_SUPPORTED_MICROVERSION)
+
     @classmethod
     def resource_setup(cls):
         super(ReplicationAdminTest, cls).resource_setup()
