@@ -32,13 +32,18 @@ class ShareIpRulesForNFSNegativeTest(base.BaseSharesMixedTest):
     protocol = "nfs"
 
     @classmethod
-    def resource_setup(cls):
-        super(ShareIpRulesForNFSNegativeTest, cls).resource_setup()
-        cls.admin_client = cls.admin_shares_v2_client
+    def skip_checks(cls):
+        super(ShareIpRulesForNFSNegativeTest, cls).skip_checks()
         if not (cls.protocol in CONF.share.enable_protocols and
                 cls.protocol in CONF.share.enable_ip_rules_for_protocols):
             msg = "IP rule tests for %s protocol are disabled" % cls.protocol
             raise cls.skipException(msg)
+
+    @classmethod
+    def resource_setup(cls):
+        super(ShareIpRulesForNFSNegativeTest, cls).resource_setup()
+        cls.admin_client = cls.admin_shares_v2_client
+
         # create share_type
         cls.share_type = cls._create_share_type()
         cls.share_type_id = cls.share_type['id']
@@ -133,7 +138,7 @@ class ShareIpRulesForNFSNegativeTest(base.BaseSharesMixedTest):
     def test_create_duplicate_single_host_rules(self, access_to):
         """Test rules for individual clients with and without max-prefix."""
         if ':' in access_to and utils.is_microversion_lt(
-                '2.38', CONF.share.max_api_microversion):
+                CONF.share.max_api_microversion, '2.38'):
             reason = ("Skipped. IPv6 rules are accepted from and beyond "
                       "API version 2.38, the configured maximum API version "
                       "is %s" % CONF.share.max_api_microversion)
